@@ -67,7 +67,7 @@ NNS.ANOVA <- function(control,
             A <- control
         }
     } else {
-        return(NNS.ANOVA.bin(control, treatment, confidence.interval, plot = plot, tails = tails))
+        return(NNS.ANOVA.bin(control, treatment, confidence.interval = confidence.interval, plot = plot, tails = tails))
     }
 
 
@@ -81,8 +81,10 @@ NNS.ANOVA <- function(control,
   #Continuous CDF for each variable from Mean of Means
         LPM_ratio <- sapply(1 : ncol(A), function(b) LPM.ratio(1, mean.of.means, A[ , b]))
 
-        lower.target = mean(sapply(1:n, function(i) LPM.VaR(.75,1,A[,i])))
-        upper.target = mean(sapply(1:n, function(i) UPM.VaR(.75,1,A[,i])))
+        lower.25.target = mean(sapply(1:n, function(i) LPM.VaR(.75,1,A[,i])))
+        upper.25.target = mean(sapply(1:n, function(i) UPM.VaR(.75,1,A[,i])))
+        lower.125.target = mean(sapply(1:n, function(i) LPM.VaR(.875,1,A[,i])))
+        upper.125.target = mean(sapply(1:n, function(i) UPM.VaR(.875,1,A[,i])))
 
 
         raw.certainties <- list()
@@ -90,8 +92,11 @@ NNS.ANOVA <- function(control,
         for(i in 1:(n - 1)){
           raw.certainties[[i]] <- sapply((i + 1) : n, function(b) NNS.ANOVA.bin(A[ , i],A[ , b],
                                                                                 mean.of.means = mean.of.means,
-                                                                                upper.target = upper.target,
-                                                                                lower.target = lower.target, plot = FALSE)$Certainty)
+                                                                                upper.25.target = upper.25.target,
+                                                                                lower.25.target = lower.25.target,
+                                                                                upper.125.target = upper.125.target,
+                                                                                lower.125.target = lower.125.target,
+                                                                                plot = FALSE)$Certainty)
         }
 
 
