@@ -19,15 +19,20 @@
 
 NNS.norm <- function(A,
                      linear = FALSE,
-                     chart.type = NULL, location = "topleft"){
+                     chart.type = NULL,
+                     location = "topleft"){
 
   m  <- colMeans(A)
   m[m==0] <- 1e-10
   RG <- m %o% (1 / m)
 
   if(!linear){
-      scale.factor <- abs(NNS.dep(A)$Dependence)
-      scales <- colMeans(RG * scale.factor)
+      if(length(m) < 10){
+        scale.factor <- abs(cor(A))
+      } else {
+        scale.factor <- abs(NNS.dep(A)$Dependence)
+      }
+    scales <- colMeans(RG * scale.factor)
   } else {
       scales <- colMeans(RG)
   }
@@ -58,15 +63,20 @@ if(!is.null(chart.type)){
         }
 
         if(chart.type == 'l' ){
-            par(mar = c(3, 3, 2, 2))
             par(mfrow = c(2, 1))
+            par(mar = c(ifelse(class(rownames(A))=="character",5,2), nchar(max(A_Normalized))*1/exp(1), 1, 2))
+
 
             matplot(A, type = 'l', col = c('steelblue', rainbow(n)), ylab = '', xaxt = 'n', lwd = 2, las = 1)
             legend(location, inset = c(0,0), c(colnames(A)), lty = 1, col = c('steelblue', rainbow(n)), bty = 'n', ncol = floor(n/sqrt(n)), lwd = 2, cex = n/sqrt(n)^exp(1))
-            axis(1, at = seq(length(A[ , 1]), 1, -round(sqrt(length(A[ , 1])))), labels = rownames(A[seq(length(A[ , 1]), 1, -round(sqrt(length(A[ , 1])))),]), las = 1, cex.axis = 1)
+            axis(1, at = seq(length(A[ , 1]), 1, -floor(sqrt(length(A[ , 1])))),
+                 labels = rownames(A[seq(length(A[ , 1]), 1, -floor(sqrt(length(A[ , 1])))),]), las = 1,
+                 cex.axis = ifelse(class(rownames(A))=="character",.75,1), las = ifelse(class(rownames(A))=="character",3,1),srt=45)
 
             matplot(A_Normalized, type = 'l', col = c('steelblue', rainbow(n)), ylab = '', xaxt = 'n', lwd = 2, las = 1)
-            axis(1, at = seq(length(A[ , 1]), 1, -round(sqrt(length(A[ , 1])))), labels = rownames(A[seq(length(A[ , 1]), 1, -round(sqrt(length(A[ , 1])))),]), las = 1, cex.axis = 1)
+            axis(1, at = seq(length(A[ , 1]), 1, -floor(sqrt(length(A[ , 1])))),
+                 labels = rownames(A[seq(length(A[ , 1]), 1, -floor(sqrt(length(A[ , 1])))),]), las = 1,
+                 cex.axis = ifelse(class(rownames(A))=="character",.75,1), las = ifelse(class(rownames(A))=="character",3,1),srt=45)
 
             legend(location, c(paste0(colnames(A), " Normalized")), lty = 1, col = c('steelblue', rainbow(n)), bty = 'n', ncol = ceiling(n/sqrt(n)), lwd = 2, cex = n/sqrt(n)^exp(1))
         }
